@@ -8,9 +8,9 @@ use Log::ger;
 use Perinci::Object;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-10'; # DATE
+our $DATE = '2024-09-28'; # DATE
 our $DIST = 'App-PDFUtils'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our %SPEC;
 
@@ -26,18 +26,6 @@ my %argspec0_files = (
     },
 );
 
-my %argspec0_files__epub = (
-    files => {
-        schema => ['array*', of=>'filename*', min_len=>1,
-                   #uniq=>1, # not yet implemented by Data::Sah
-               ],
-        req => 1,
-        pos => 0,
-        slurpy => 1,
-        'x.element_completion' => [filename => {filter => sub { /\.epub$/i }}],
-    },
-);
-
 our %argspec0_file = (
     file => {
         summary => 'Input file',
@@ -74,25 +62,29 @@ our %argspecopt_return_output_file = (
     return_output_file => {
         summary => 'Return the path of output file instead',
         schema => 'bool*',
-        description => <<'_',
+        description => <<'MARKDOWN',
 
 This is useful when you do not specify an output file but do not want to show
 the converted document to stdout, but instead want to get the path to a
 temporary output file.
 
-_
+MARKDOWN
     },
 );
 
 $SPEC{add_pdf_password} = {
     v => 1.1,
     summary => 'Password-protect PDF files',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This program is a wrapper for <prog:qpdf> to password-protect PDF files
-(in-place). This is the counterpart for <prog:remove-pdf-password>.
+(in-place). This is the counterpart for <prog:remove-pdf-password>. Why use this
+wrapper instead of **qpdf** directly? This wrapper offers configuration file
+support, where you can put the password(s) you want to use there. The wrapper
+also offers multiple file support and additional options, e.g. whether to create
+backup.
 
-_
+MARKDOWN
     args => {
         %argspec0_files,
         password => {
@@ -170,12 +162,12 @@ sub add_pdf_password {
 $SPEC{remove_pdf_password} = {
     v => 1.1,
     summary => 'Remove password from PDF files',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This program is a wrapper for <prog:qpdf> to remove passwords from PDF files
 (in-place).
 
-The motivation for this program is the increasing occurence of financial
+The motivation for this wrapper is the increasing occurence of financial
 institutions sending financial statements or documents in the format of
 password-protected PDF file. This is annoying when we want to archive the file
 or use it in an organization because we have to remember different passwords for
@@ -183,6 +175,11 @@ different financial institutions and re-enter the password everytime we want to
 use the file. (The banks could've sent the PDF in a password-protected .zip, or
 use PGP-encrypted email, but I digress.)
 
+Compared to using **qpdf** directly, this wrapper offers some additional
+features/options and convenience, for example: multiple file support, multiple
+password matching attempt, configuration file, option whether you want backup,
+etc.
+
 You can provide the passwords to be tried in a configuration file,
 `~/remove-pdf-password.conf`, e.g.:
 
@@ -194,7 +191,7 @@ or:
 
     passwords = ["pass1", "pass2", "pass3"]
 
-_
+MARKDOWN
     args => {
         %argspec0_files,
         passwords => {
@@ -279,6 +276,12 @@ sub remove_pdf_password {
 $SPEC{pdf_has_password} = {
     v => 1.1,
     summary => 'Check if PDF file has password',
+    description => <<'MARKDOWN',
+
+This is a wrapper for `qpdf --check`. The wrapper offers additional options like
+`--quiet``.
+
+MARKDOWN
     args => {
         %argspec0_file,
         %argspecopt_quiet,
@@ -313,13 +316,19 @@ sub pdf_has_password {
 $SPEC{convert_pdf_to_text} = {
     v => 1.1,
     summary => 'Convert PDF file to text',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This utility uses one of the following backends:
 
 * pdftotext
 
-_
+as well as optionally uses <prog:pdftk> to manipulate PDF, and <prog:fmt> to
+format text. It offers some options and conveniences like page ranges, output
+file specification, whether to overwrite existing files, etc.
+
+TODO: add ocrmypdf as backend.
+
+MARKDOWN
     args => {
         %argspec0_file,
         %argspecopt1_output,
@@ -428,17 +437,17 @@ sub convert_pdf_to_text {
 $SPEC{compress_pdf} = {
     v => 1.1,
     summary => 'Make PDF smaller',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This utility is a wrapper for <prog:gs> (GhostScript) and is equivalent to the
 following command:
 
     % gs -sDEVICE=pdfwrite -dCompatibilityLevel=1.4 -dPDFSETTINGS=/screen -dNOPAUSE -dQUIET -dBATCH -sOutputFile=output.pdf input.pdf
 
-with support for multiple files and output files automatically named
-`INPUT.compressed.pdf`.
+This wrapper offers support for multiple files and automatically naming output
+`INPUT.compressed.pdf` by default.
 
-_
+MARKDOWN
     args => {
         %argspec0_files,
         %argspecopt_overwrite,
@@ -520,70 +529,6 @@ sub compress_pdf {
     $envres->as_struct;
 }
 
-$SPEC{convert_epub_to_pdf} = {
-    v => 1.1,
-    summary => 'Convert epub file to PDF',
-    description => <<'_',
-
-This utility is a simple wrapper to `ebook-convert`. It allows setting output
-filenames (`foo.epub.pdf`) so you don't have to specify them manually. It also
-allows processing multiple files in a single invocation
-
-_
-    args => {
-        %argspec0_files__epub,
-        %argspecopt_overwrite,
-    },
-    deps => {
-        prog => 'ebook-convert',
-    },
-};
-sub convert_epub_to_pdf {
-    my %args = @_;
-
-    require IPC::System::Options;
-
-    my $envres = envresmulti();
-
-    my $i = 0;
-    for my $input_file (@{ $args{files} }) {
-        log_info "[%d/%d] Processing file %s ...", ++$i, scalar(@{ $args{files} }), $input_file;
-        $input_file =~ /(.+)\.(\w+)\z/ or do {
-            $envres->add_result(412, "Please supply input file with extension in its name (e.g. foo.epub instead of foo)", {item_id=>$input_file});
-            next;
-        };
-        my ($name, $ext) = ($1, $2);
-        $ext =~ /\Aepub\z/i or do {
-            $envres->add_result(412, "Input file '$input_file' does not have .epub extension", {item_id=>$input_file});
-            next;
-        };
-
-        my $output_file = "$input_file.pdf";
-
-        if (-e $output_file) {
-            if ($args{overwrite}) {
-                log_info "Unlinking existing PDF file %s ...", $output_file;
-                unlink $output_file;
-            } else {
-                $envres->add_result(412, "Output file '$output_file' already exists, not overwriting (use --overwrite (-O) to overwrite)", {item_id=>$input_file});
-                next;
-            }
-        }
-
-        IPC::System::Options::system(
-            {log=>1},
-            "ebook-convert", $input_file, $output_file);
-        my $exit_code = $? < 0 ? $? : $? >> 8;
-        if ($exit_code) {
-            $envres->add_result(500, "ebook-convert didn't return successfully, exit code=$exit_code", {item_id=>$input_file});
-        } else {
-            $envres->add_result(200, "OK", {item_id=>$input_file});
-        }
-    } # for $input_file
-
-    $envres->as_struct;
-}
-
 1;
 # ABSTRACT: Command-line utilities related to PDF files
 
@@ -599,34 +544,32 @@ App::PDFUtils - Command-line utilities related to PDF files
 
 =head1 VERSION
 
-This document describes version 0.015 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2023-02-10.
+This document describes version 0.016 of App::PDFUtils (from Perl distribution App-PDFUtils), released on 2024-09-28.
 
 =head1 SYNOPSIS
 
+=head1 DESCRIPTION
+
 This distribution provides tha following command-line utilities related to PDF
 files:
 
 =over
 
-=item * L<add-pdf-password>
+=item 1. L<add-pdf-password>
 
-=item * L<compress-pdf>
+=item 2. L<compress-pdf>
 
-=item * L<convert-epub-to-pdf>
+=item 3. L<grep-from-pdf>
 
-=item * L<epub2pdf>
+=item 4. L<less-pdf-text>
 
-=item * L<grep-from-pdf>
+=item 5. L<pdf-has-password>
 
-=item * L<less-pdf-text>
+=item 6. L<pdfgrep>
 
-=item * L<pdf-has-password>
+=item 7. L<pdfnopass>
 
-=item * L<pdfgrep>
-
-=item * L<pdfnopass>
-
-=item * L<remove-pdf-password>
+=item 8. L<remove-pdf-password>
 
 =back
 
@@ -642,7 +585,11 @@ Usage:
 Password-protect PDF files.
 
 This program is a wrapper for L<qpdf> to password-protect PDF files
-(in-place). This is the counterpart for L<remove-pdf-password>.
+(in-place). This is the counterpart for L<remove-pdf-password>. Why use this
+wrapper instead of B<qpdf> directly? This wrapper offers configuration file
+support, where you can put the password(s) you want to use there. The wrapper
+also offers multiple file support and additional options, e.g. whether to create
+backup.
 
 This function is not exported.
 
@@ -691,8 +638,8 @@ following command:
 
  % gs -sDEVICE=pdfwrite -dCompatibilityLevel=1.4 -dPDFSETTINGS=/screen -dNOPAUSE -dQUIET -dBATCH -sOutputFile=output.pdf input.pdf
 
-with support for multiple files and output files automatically named
-C<INPUT.compressed.pdf>.
+This wrapper offers support for multiple files and automatically naming output
+C<INPUT.compressed.pdf> by default.
 
 This function is not exported.
 
@@ -728,48 +675,6 @@ Return value:  (any)
 
 
 
-=head2 convert_epub_to_pdf
-
-Usage:
-
- convert_epub_to_pdf(%args) -> [$status_code, $reason, $payload, \%result_meta]
-
-Convert epub file to PDF.
-
-This utility is a simple wrapper to C<ebook-convert>. It allows setting output
-filenames (C<foo.epub.pdf>) so you don't have to specify them manually. It also
-allows processing multiple files in a single invocation
-
-This function is not exported.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<files>* => I<array[filename]>
-
-(No description)
-
-=item * B<overwrite> => I<bool>
-
-(No description)
-
-
-=back
-
-Returns an enveloped result (an array).
-
-First element ($status_code) is an integer containing HTTP-like status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-($reason) is a string containing error message, or something like "OK" if status is
-200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
-element (%result_meta) is called result metadata and is optional, a hash
-that contains extra information, much like how HTTP response headers provide additional metadata.
-
-Return value:  (any)
-
-
-
 =head2 convert_pdf_to_text
 
 Usage:
@@ -786,6 +691,12 @@ This utility uses one of the following backends:
 
 =back
 
+as well as optionally uses L<pdftk> to manipulate PDF, and L<fmt> to
+format text. It offers some options and conveniences like page ranges, output
+file specification, whether to overwrite existing files, etc.
+
+TODO: add ocrmypdf as backend.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
@@ -848,6 +759,9 @@ Usage:
 
 Check if PDF file has password.
 
+This is a wrapper for C<qpdf --check>. The wrapper offers additional options like
+`--quiet``.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
@@ -889,7 +803,7 @@ Remove password from PDF files.
 This program is a wrapper for L<qpdf> to remove passwords from PDF files
 (in-place).
 
-The motivation for this program is the increasing occurence of financial
+The motivation for this wrapper is the increasing occurence of financial
 institutions sending financial statements or documents in the format of
 password-protected PDF file. This is annoying when we want to archive the file
 or use it in an organization because we have to remember different passwords for
@@ -897,6 +811,11 @@ different financial institutions and re-enter the password everytime we want to
 use the file. (The banks could've sent the PDF in a password-protected .zip, or
 use PGP-encrypted email, but I digress.)
 
+Compared to using B<qpdf> directly, this wrapper offers some additional
+features/options and convenience, for example: multiple file support, multiple
+password matching attempt, configuration file, option whether you want backup,
+etc.
+
 You can provide the passwords to be tried in a configuration file,
 C<~/remove-pdf-password.conf>, e.g.:
 
@@ -976,7 +895,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2022, 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2022, 2021, 2020, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
